@@ -6,6 +6,7 @@ use crate::rule::{
 };
 use crate::utils::early_returns;
 use crate::utils::range_utils::calculate_url_range;
+use crate::utils::regex_cache::EMAIL_PATTERN;
 
 use crate::lint_context::LintContext;
 use fancy_regex::Regex as FancyRegex;
@@ -15,12 +16,12 @@ use regex::Regex;
 
 lazy_static! {
     // Simple pattern to quickly check if a line might contain a URL or email
-    static ref URL_QUICK_CHECK: Regex = Regex::new(r#"(?:https?|ftp)://|@"#).unwrap();
+    static ref URL_QUICK_CHECK: Regex = Regex::new(r#"(?:https?|ftps?)://|@"#).unwrap();
 
     // Use fancy-regex for look-behind/look-ahead
     // Updated to support IPv6 addresses in square brackets
-    static ref URL_REGEX: FancyRegex = FancyRegex::new(r#"(?<![\w\[\(\<])((?:https?|ftp)://(?:\[[0-9a-fA-F:%]+\]|[^\s<>\[\]()\\'\"]+)(?::\d+)?(?:/[^\s<>\[\]()\\'\"]*)?(?:\?[^\s<>\[\]()\\'\"]*)?(?:#[^\s<>\[\]()\\'\"]*)?)"#).unwrap();
-    static ref URL_FIX_REGEX: FancyRegex = FancyRegex::new(r#"(?<![\w\[\(\<])((?:https?|ftp)://(?:\[[0-9a-fA-F:%]+\]|[^\s<>\[\]()\\'\"]+)(?::\d+)?(?:/[^\s<>\[\]()\\'\"]*)?(?:\?[^\s<>\[\]()\\'\"]*)?(?:#[^\s<>\[\]()\\'\"]*)?)"#).unwrap();
+    static ref URL_REGEX: FancyRegex = FancyRegex::new(r#"(?<![\w\[\(\<])((?:https?|ftps?)://(?:\[[0-9a-fA-F:%]+\]|[^\s<>\[\]()\\'\"]+)(?::\d+)?(?:/[^\s<>\[\]()\\'\"]*)?(?:\?[^\s<>\[\]()\\'\"]*)?(?:#[^\s<>\[\]()\\'\"]*)?)"#).unwrap();
+    static ref URL_FIX_REGEX: FancyRegex = FancyRegex::new(r#"(?<![\w\[\(\<])((?:https?|ftps?)://(?:\[[0-9a-fA-F:%]+\]|[^\s<>\[\]()\\'\"]+)(?::\d+)?(?:/[^\s<>\[\]()\\'\"]*)?(?:\?[^\s<>\[\]()\\'\"]*)?(?:#[^\s<>\[\]()\\'\"]*)?)"#).unwrap();
 
     // Pattern to match markdown link format - capture destination in Group 1
     // Updated to handle nested brackets in badge links like [![badge](img)](link)
@@ -28,10 +29,7 @@ lazy_static! {
 
     // Pattern to match angle bracket link format (URLs and emails)
     // Updated to support IPv6 addresses
-    static ref ANGLE_LINK_PATTERN: Regex = Regex::new(r#"<((?:https?|ftp)://(?:\[[0-9a-fA-F:]+(?:%[a-zA-Z0-9]+)?\]|[^>]+)|[^@\s]+@[^@\s]+\.[^@\s>]+)>"#).unwrap();
-
-    // Pattern to match code fences
-    static ref CODE_FENCE_RE: Regex = Regex::new(r#"^(`{3,}|~{3,})"#).unwrap();
+    static ref ANGLE_LINK_PATTERN: Regex = Regex::new(r#"<((?:https?|ftps?)://(?:\[[0-9a-fA-F:]+(?:%[a-zA-Z0-9]+)?\]|[^>]+)|[^@\s]+@[^@\s]+\.[^@\s>]+)>"#).unwrap();
 
     // Add regex to identify lines containing only a badge link
     static ref BADGE_LINK_LINE: Regex = Regex::new(r#"^\s*\[!\[[^\]]*\]\([^)]*\)\]\([^)]*\)\s*$"#).unwrap();
@@ -49,22 +47,21 @@ lazy_static! {
     // Now supports IPv6 addresses in square brackets
     // Note: We need two separate patterns - one for IPv6 and one for regular URLs
     // Updated to avoid matching partial IPv6 patterns (e.g., "https://::1]" without opening bracket)
-    static ref SIMPLE_URL_REGEX: Regex = Regex::new(r#"(https?|ftp)://(?:\[[0-9a-fA-F:%.]+\](?::\d+)?|[^\s<>\[\]()\\'\"`:\]]+(?::\d+)?)(?:/[^\s<>\[\]()\\'\"`]*)?(?:\?[^\s<>\[\]()\\'\"`]*)?(?:#[^\s<>\[\]()\\'\"`]*)?"#).unwrap();
-    
+    static ref SIMPLE_URL_REGEX: Regex = Regex::new(r#"(https?|ftps?)://(?:\[[0-9a-fA-F:%.]+\](?::\d+)?|[^\s<>\[\]()\\'\"`:\]]+(?::\d+)?)(?:/[^\s<>\[\]()\\'\"`]*)?(?:\?[^\s<>\[\]()\\'\"`]*)?(?:#[^\s<>\[\]()\\'\"`]*)?"#).unwrap();
+
     // Special pattern just for IPv6 URLs to handle them separately
     // Note: This is permissive to match markdownlint behavior, allowing technically invalid IPv6 for examples
-    static ref IPV6_URL_REGEX: Regex = Regex::new(r#"(https?|ftp)://\[[0-9a-fA-F:%.\-a-zA-Z]+\](?::\d+)?(?:/[^\s<>\[\]()\\'\"`]*)?(?:\?[^\s<>\[\]()\\'\"`]*)?(?:#[^\s<>\[\]()\\'\"`]*)?"#).unwrap();
-
-    // Add regex for email addresses - matches markdownlint behavior
-    // Detects email addresses that should be autolinked like URLs
-    static ref EMAIL_REGEX: Regex = Regex::new(r#"[a-zA-Z0-9._%+-]+@[a-zA-Z0-9.-]+\.[a-zA-Z]{2,}"#).unwrap();
+    static ref IPV6_URL_REGEX: Regex = Regex::new(r#"(https?|ftps?)://\[[0-9a-fA-F:%.\-a-zA-Z]+\](?::\d+)?(?:/[^\s<>\[\]()\\'\"`]*)?(?:\?[^\s<>\[\]()\\'\"`]*)?(?:#[^\s<>\[\]()\\'\"`]*)?"#).unwrap();
 
     // Add regex for reference definitions
     // Updated to support IPv6 addresses
-    static ref REFERENCE_DEF_RE: Regex = Regex::new(r"^\s*\[[^\]]+\]:\s*(?:https?|ftp)://\S+$").unwrap();
+    static ref REFERENCE_DEF_RE: Regex = Regex::new(r"^\s*\[[^\]]+\]:\s*(?:https?|ftps?)://\S+$").unwrap();
 
     // Pattern to match URLs inside HTML attributes (src, href, srcset, etc.)
     static ref HTML_ATTRIBUTE_URL: Regex = Regex::new(r#"(?:src|href|srcset|content|data-\w+)\s*=\s*["']([^"']*)["']"#).unwrap();
+
+    // Pattern to match HTML comments
+    static ref HTML_COMMENT_PATTERN: Regex = Regex::new(r#"<!--[\s\S]*?-->"#).unwrap();
 }
 
 #[derive(Default, Clone)]
@@ -145,6 +142,13 @@ impl MD034NoBareUrls {
             }
         }
 
+        // HTML comments: <!-- url -->
+        for cap in HTML_COMMENT_PATTERN.captures_iter(content) {
+            if let Some(comment) = cap.get(0) {
+                excluded_ranges.push((comment.start(), comment.end()));
+            }
+        }
+
         // Sort and merge overlapping ranges
         excluded_ranges.sort_by_key(|r| r.0);
         let mut merged: Vec<(usize, usize)> = Vec::new();
@@ -161,63 +165,61 @@ impl MD034NoBareUrls {
         // Now find all URLs and emails in the content and check if they're excluded
         // We'll combine URL and email detection for efficiency
         let mut all_matches: Vec<(usize, usize, bool)> = Vec::new(); // (start, end, is_email)
-        
+
         // Early exit if no potential URLs/emails based on quick check
         if !content.contains("://") && !content.contains('@') {
             return Ok(warnings);
         }
 
         // Use line-based processing for better cache locality
-        for (_line_idx, line_info) in ctx.lines.iter().enumerate() {
+        for line_info in ctx.lines.iter() {
             let line_content = &line_info.content;
-            
+
             // Skip lines in code blocks
             if line_info.in_code_block {
                 continue;
             }
-            
+
             // Quick check if line might contain URLs or emails
             if !line_content.contains("://") && !line_content.contains('@') {
                 continue;
             }
-            
+
             // Check for URLs in this line
             for url_match in SIMPLE_URL_REGEX.find_iter(line_content) {
                 let start_in_line = url_match.start();
                 let end_in_line = url_match.end();
                 let matched_str = &line_content[start_in_line..end_in_line];
-                
+
                 // Skip invalid IPv6 patterns
                 if matched_str.contains("::") && !matched_str.contains('[') && matched_str.contains(']') {
                     continue;
                 }
-                
+
                 let global_start = line_info.byte_offset + start_in_line;
                 let global_end = line_info.byte_offset + end_in_line;
                 all_matches.push((global_start, global_end, false));
             }
-            
+
             // Check for IPv6 URLs
             for url_match in IPV6_URL_REGEX.find_iter(line_content) {
                 let global_start = line_info.byte_offset + url_match.start();
                 let global_end = line_info.byte_offset + url_match.end();
-                
+
                 // Remove any overlapping regular URL matches
-                all_matches.retain(|(start, end, _)| {
-                    !(*start < global_end && *end > global_start)
-                });
-                
+                all_matches.retain(|(start, end, _)| !(*start < global_end && *end > global_start));
+
                 all_matches.push((global_start, global_end, false));
             }
-            
+
             // Check for emails in this line
-            for email_match in EMAIL_REGEX.find_iter(line_content) {
+            for email_match in EMAIL_PATTERN.find_iter(line_content) {
                 let global_start = line_info.byte_offset + email_match.start();
                 let global_end = line_info.byte_offset + email_match.end();
                 all_matches.push((global_start, global_end, true));
             }
         }
-        
+
         // Process all matches
         for (match_start, match_end_orig, is_email) in all_matches {
             let mut match_end = match_end_orig;
@@ -241,7 +243,7 @@ impl MD034NoBareUrls {
                 content.get(match_start - 1..match_start)
             };
             let after = content.get(match_end..match_end + 1);
-            
+
             let is_valid_boundary = if is_email {
                 before.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_" && c != ".")
                     && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_" && c != ".")
@@ -249,7 +251,7 @@ impl MD034NoBareUrls {
                 before.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_")
                     && after.is_none_or(|c| !c.chars().next().unwrap().is_alphanumeric() && c != "_")
             };
-            
+
             if !is_valid_boundary {
                 continue;
             }
@@ -259,15 +261,20 @@ impl MD034NoBareUrls {
                 continue;
             }
 
-            // Skip if within any excluded range (link/image dest)
-            let in_any_range = merged.iter().any(|(start, end)| match_start >= *start && match_end <= *end);
+            // Skip if within any excluded range (link/image dest/HTML comment)
+            let in_any_range = merged.iter().any(|(start, end)| {
+                // For HTML comments and other exclusions, check if URL overlaps the range
+                (match_start >= *start && match_start < *end)
+                    || (match_end > *start && match_end <= *end)
+                    || (match_start < *start && match_end > *end)
+            });
             if in_any_range {
                 continue;
             }
 
             // Get line information efficiently
             let (line_num, col_num) = ctx.offset_to_line_col(match_start);
-            
+
             // Skip reference definitions for URLs
             if !is_email {
                 if let Some(line_info) = ctx.line_info(line_num) {
@@ -370,7 +377,7 @@ impl MD034NoBareUrls {
                 }
 
                 // Check for email addresses
-                for email_match in EMAIL_REGEX.find_iter(text_str) {
+                for email_match in EMAIL_PATTERN.find_iter(text_str) {
                     let email_start = email_match.start();
                     let email_end = email_match.end();
                     let before = if email_start == 0 {
@@ -508,6 +515,7 @@ impl Rule for MD034NoBareUrls {
         if !content.contains("http://")
             && !content.contains("https://")
             && !content.contains("ftp://")
+            && !content.contains("ftps://")
             && !content.contains('@')
         {
             return Ok(Vec::new());
@@ -615,6 +623,7 @@ impl crate::utils::document_structure::DocumentStructureExtensions for MD034NoBa
             && (content.contains("http://")
                 || content.contains("https://")
                 || content.contains("ftp://")
+                || content.contains("ftps://")
                 || content.contains('@'))
     }
 }
@@ -638,7 +647,6 @@ mod tests {
         assert!(!URL_QUICK_CHECK.is_match("This has no URL"));
     }
 
-
     #[test]
     fn test_multiple_badges_and_links_on_one_line() {
         let rule = MD034NoBareUrls;
