@@ -1,8 +1,10 @@
 use crate::rule::{LintError, LintResult, LintWarning, Rule, RuleCategory, Severity};
+use crate::rule_config_serde::RuleConfig;
 use crate::utils::document_structure::{DocumentStructure, DocumentStructureExtensions};
 use crate::utils::range_utils::calculate_heading_range;
 use lazy_static::lazy_static;
 use regex::Regex;
+use serde::{Deserialize, Serialize};
 
 lazy_static! {
     // Pattern for ATX headings
@@ -11,17 +13,69 @@ lazy_static! {
     static ref SETEXT_UNDERLINE: Regex = Regex::new(r"^([=-]+)$").unwrap();
 }
 
+/// Configuration for MD043 rule
+#[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
+#[serde(rename_all = "kebab-case")]
+pub struct MD043Config {
+    /// Required heading patterns
+    #[serde(default = "default_headings")]
+    pub headings: Vec<String>,
+    /// Case-sensitive matching (default: false)
+    #[serde(default = "default_match_case")]
+    pub match_case: bool,
+}
+
+impl Default for MD043Config {
+    fn default() -> Self {
+        Self {
+            headings: default_headings(),
+            match_case: default_match_case(),
+        }
+    }
+}
+
+fn default_headings() -> Vec<String> {
+    Vec::new()
+}
+
+fn default_match_case() -> bool {
+    false
+}
+
+impl RuleConfig for MD043Config {
+    const RULE_NAME: &'static str = "MD043";
+}
+
 /// Rule MD043: Required headings present
 ///
 /// See [docs/md043.md](../../docs/md043.md) for full documentation, configuration, and examples.
-#[derive(Clone)]
+#[derive(Clone, Default)]
 pub struct MD043RequiredHeadings {
-    headings: Vec<String>,
+    config: MD043Config,
 }
 
 impl MD043RequiredHeadings {
     pub fn new(headings: Vec<String>) -> Self {
-        Self { headings }
+        Self {
+            config: MD043Config {
+                headings,
+                match_case: default_match_case(),
+            },
+        }
+    }
+
+    /// Create a new instance with the given configuration
+    pub fn from_config_struct(config: MD043Config) -> Self {
+        Self { config }
+    }
+
+    /// Compare two headings based on the match_case configuration
+    fn headings_match(&self, expected: &str, actual: &str) -> bool {
+        if self.config.match_case {
+            expected == actual
+        } else {
+            expected.to_lowercase() == actual.to_lowercase()
+        }
     }
 
     fn extract_headings(&self, ctx: &crate::lint_context::LintContext) -> Vec<String> {
@@ -29,7 +83,9 @@ impl MD043RequiredHeadings {
 
         for line_info in &ctx.lines {
             if let Some(heading) = &line_info.heading {
-                result.push(heading.text.trim().to_string());
+                // Reconstruct the full heading format with the hash symbols
+                let full_heading = format!("{} {}", heading.marker, heading.text.trim());
+                result.push(full_heading);
             }
         }
 
@@ -59,20 +115,30 @@ impl Rule for MD043RequiredHeadings {
         let actual_headings = self.extract_headings(ctx);
 
         // If no required headings are specified, the rule is disabled
-        if self.headings.is_empty() {
+        if self.config.headings.is_empty() {
             return Ok(warnings);
         }
 
-        if actual_headings != self.headings {
+        // Check if headings match based on case sensitivity configuration
+        let headings_match = if actual_headings.len() != self.config.headings.len() {
+            false
+        } else {
+            actual_headings
+                .iter()
+                .zip(self.config.headings.iter())
+                .all(|(actual, expected)| self.headings_match(expected, actual))
+        };
+
+        if !headings_match {
             // If no headings found but we have required headings, create a warning
-            if actual_headings.is_empty() && !self.headings.is_empty() {
+            if actual_headings.is_empty() && !self.config.headings.is_empty() {
                 warnings.push(LintWarning {
                     rule_name: Some(self.name()),
                     line: 1,
                     column: 1,
                     end_line: 1,
                     end_column: 2,
-                    message: format!("Required headings not found: {:?}", self.headings),
+                    message: format!("Required headings not found: {:?}", self.config.headings),
                     severity: Severity::Warning,
                     fix: None,
                 });
@@ -109,7 +175,7 @@ impl Rule for MD043RequiredHeadings {
                     end_column: 2,
                     message: format!(
                         "Heading structure does not match required structure. Expected: {:?}, Found: {:?}",
-                        self.headings, actual_headings
+                        self.config.headings, actual_headings
                     ),
                     severity: Severity::Warning,
                     fix: None,
@@ -123,18 +189,18 @@ impl Rule for MD043RequiredHeadings {
     fn fix(&self, ctx: &crate::lint_context::LintContext) -> Result<String, LintError> {
         let content = ctx.content;
         // If no required headings are specified, return content as is
-        if self.headings.is_empty() {
+        if self.config.headings.is_empty() {
             return Ok(content.to_string());
         }
 
         let mut result = String::new();
 
         // Add required headings
-        for (idx, heading) in self.headings.iter().enumerate() {
+        for (idx, heading) in self.config.headings.iter().enumerate() {
             if idx > 0 {
                 result.push_str("\n\n");
             }
-            result.push_str(&format!("# {heading}"));
+            result.push_str(heading);
         }
 
         Ok(result)
@@ -158,7 +224,7 @@ impl Rule for MD043RequiredHeadings {
     /// Check if this rule should be skipped
     fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
         // Skip if no heading requirements or content is empty
-        if self.headings.is_empty() || ctx.content.is_empty() {
+        if self.config.headings.is_empty() || ctx.content.is_empty() {
             return true;
         }
 
@@ -172,13 +238,27 @@ impl Rule for MD043RequiredHeadings {
         self
     }
 
+    fn default_config_section(&self) -> Option<(String, toml::Value)> {
+        let default_config = MD043Config::default();
+        let json_value = serde_json::to_value(&default_config).ok()?;
+        let toml_value = crate::rule_config_serde::json_to_toml_value(&json_value)?;
+        if let toml::Value::Table(table) = toml_value {
+            if !table.is_empty() {
+                Some((MD043Config::RULE_NAME.to_string(), toml::Value::Table(table)))
+            } else {
+                None
+            }
+        } else {
+            None
+        }
+    }
+
     fn from_config(config: &crate::config::Config) -> Box<dyn Rule>
     where
         Self: Sized,
     {
-        let headings =
-            crate::config::get_rule_config_value::<Vec<String>>(config, "MD043", "headings").unwrap_or_default();
-        Box::new(MD043RequiredHeadings::new(headings))
+        let rule_config = crate::rule_config_serde::load_rule_config::<MD043Config>(config);
+        Box::new(MD043RequiredHeadings::from_config_struct(rule_config))
     }
 }
 
@@ -188,7 +268,7 @@ impl DocumentStructureExtensions for MD043RequiredHeadings {
         _ctx: &crate::lint_context::LintContext,
         doc_structure: &DocumentStructure,
     ) -> bool {
-        !doc_structure.heading_lines.is_empty() || !self.headings.is_empty()
+        !doc_structure.heading_lines.is_empty() || !self.config.headings.is_empty()
     }
 }
 
@@ -200,8 +280,8 @@ mod tests {
 
     #[test]
     fn test_extract_headings_code_blocks() {
-        // Create rule with required headings
-        let required = vec!["Test Document".to_string(), "Real heading 2".to_string()];
+        // Create rule with required headings (now with hash symbols)
+        let required = vec!["# Test Document".to_string(), "## Real heading 2".to_string()];
         let rule = MD043RequiredHeadings::new(required);
 
         // Test 1: Basic content with code block
@@ -210,7 +290,7 @@ mod tests {
         let actual_headings = rule.extract_headings(&ctx);
         assert_eq!(
             actual_headings,
-            vec!["Test Document".to_string(), "Real heading 2".to_string()],
+            vec!["# Test Document".to_string(), "## Real heading 2".to_string()],
             "Should extract correct headings and ignore code blocks"
         );
 
@@ -220,15 +300,19 @@ mod tests {
         let actual_headings = rule.extract_headings(&ctx);
         assert_eq!(
             actual_headings,
-            vec!["Test Document".to_string(), "Not Real heading 2".to_string()],
+            vec!["# Test Document".to_string(), "## Not Real heading 2".to_string()],
             "Should extract actual headings including mismatched ones"
         );
     }
 
     #[test]
     fn test_with_document_structure() {
-        // Test with required headings
-        let required = vec!["Introduction".to_string(), "Method".to_string(), "Results".to_string()];
+        // Test with required headings (now with hash symbols)
+        let required = vec![
+            "# Introduction".to_string(),
+            "# Method".to_string(),
+            "# Results".to_string(),
+        ];
         let rule = MD043RequiredHeadings::new(required);
 
         // Test with matching headings
@@ -255,10 +339,16 @@ mod tests {
             .unwrap();
         assert!(!warnings.is_empty(), "Expected warnings when headings are missing");
 
-        // Test with setext headings
+        // Test with setext headings - use the correct format (marker text)
+        let required_setext = vec![
+            "=========== Introduction".to_string(),
+            "------ Method".to_string(),
+            "======= Results".to_string(),
+        ];
+        let rule_setext = MD043RequiredHeadings::new(required_setext);
         let content = "Introduction\n===========\n\nContent\n\nMethod\n------\n\nMore content\n\nResults\n=======\n\nFinal content";
         let structure = document_structure_from_str(content);
-        let warnings = rule
+        let warnings = rule_setext
             .check_with_structure(&LintContext::new(content), &structure)
             .unwrap();
         assert!(warnings.is_empty(), "Expected no warnings for matching setext headings");
@@ -347,4 +437,168 @@ mod tests {
             "Should not skip content with ATX heading with closing hashes"
         );
     }
+
+    #[test]
+    fn test_config_match_case_sensitive() {
+        let config = MD043Config {
+            headings: vec!["# Introduction".to_string(), "# Method".to_string()],
+            match_case: true,
+        };
+        let rule = MD043RequiredHeadings::from_config_struct(config);
+
+        // Should fail with different case
+        let content = "# introduction\n\n# method";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            !result.is_empty(),
+            "Should detect case mismatch when match_case is true"
+        );
+    }
+
+    #[test]
+    fn test_config_match_case_insensitive() {
+        let config = MD043Config {
+            headings: vec!["# Introduction".to_string(), "# Method".to_string()],
+            match_case: false,
+        };
+        let rule = MD043RequiredHeadings::from_config_struct(config);
+
+        // Should pass with different case
+        let content = "# introduction\n\n# method";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(result.is_empty(), "Should allow case mismatch when match_case is false");
+    }
+
+    #[test]
+    fn test_config_case_insensitive_mixed() {
+        let config = MD043Config {
+            headings: vec!["# Introduction".to_string(), "# METHOD".to_string()],
+            match_case: false,
+        };
+        let rule = MD043RequiredHeadings::from_config_struct(config);
+
+        // Should pass with mixed case variations
+        let content = "# INTRODUCTION\n\n# method";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            result.is_empty(),
+            "Should allow mixed case variations when match_case is false"
+        );
+    }
+
+    #[test]
+    fn test_config_case_sensitive_exact_match() {
+        let config = MD043Config {
+            headings: vec!["# Introduction".to_string(), "# Method".to_string()],
+            match_case: true,
+        };
+        let rule = MD043RequiredHeadings::from_config_struct(config);
+
+        // Should pass with exact case match
+        let content = "# Introduction\n\n# Method";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(
+            result.is_empty(),
+            "Should pass with exact case match when match_case is true"
+        );
+    }
+
+    #[test]
+    fn test_default_config() {
+        let rule = MD043RequiredHeadings::default();
+
+        // Should be disabled with empty headings
+        let content = "# Any heading\n\n# Another heading";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(result.is_empty(), "Should be disabled with default empty headings");
+    }
+
+    #[test]
+    fn test_default_config_section() {
+        let rule = MD043RequiredHeadings::default();
+        let config_section = rule.default_config_section();
+
+        assert!(config_section.is_some());
+        let (name, value) = config_section.unwrap();
+        assert_eq!(name, "MD043");
+
+        // Should contain both headings and match_case options with default values
+        if let toml::Value::Table(table) = value {
+            assert!(table.contains_key("headings"));
+            assert!(table.contains_key("match-case"));
+            assert_eq!(table["headings"], toml::Value::Array(vec![]));
+            assert_eq!(table["match-case"], toml::Value::Boolean(false));
+        } else {
+            panic!("Expected TOML table");
+        }
+    }
+
+    #[test]
+    fn test_headings_match_case_sensitive() {
+        let config = MD043Config {
+            headings: vec![],
+            match_case: true,
+        };
+        let rule = MD043RequiredHeadings::from_config_struct(config);
+
+        assert!(rule.headings_match("Test", "Test"));
+        assert!(!rule.headings_match("Test", "test"));
+        assert!(!rule.headings_match("test", "Test"));
+    }
+
+    #[test]
+    fn test_headings_match_case_insensitive() {
+        let config = MD043Config {
+            headings: vec![],
+            match_case: false,
+        };
+        let rule = MD043RequiredHeadings::from_config_struct(config);
+
+        assert!(rule.headings_match("Test", "Test"));
+        assert!(rule.headings_match("Test", "test"));
+        assert!(rule.headings_match("test", "Test"));
+        assert!(rule.headings_match("TEST", "test"));
+    }
+
+    #[test]
+    fn test_config_empty_headings() {
+        let config = MD043Config {
+            headings: vec![],
+            match_case: true,
+        };
+        let rule = MD043RequiredHeadings::from_config_struct(config);
+
+        // Should skip processing when no headings are required
+        let content = "# Any heading\n\n# Another heading";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+
+        assert!(result.is_empty(), "Should be disabled with empty headings list");
+    }
+
+    #[test]
+    fn test_fix_respects_configuration() {
+        let config = MD043Config {
+            headings: vec!["# Title".to_string(), "# Content".to_string()],
+            match_case: false,
+        };
+        let rule = MD043RequiredHeadings::from_config_struct(config);
+
+        let content = "Wrong content";
+        let ctx = LintContext::new(content);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        let expected = "# Title\n\n# Content";
+        assert_eq!(fixed, expected);
+    }
 }
