@@ -1,9 +1,11 @@
 use crate::rule::{Fix, LintError, LintResult, LintWarning, Rule, Severity};
+use crate::rule_config_serde::RuleConfig;
 use crate::utils::document_structure::DocumentStructure;
 use crate::utils::range_utils::calculate_line_range;
 use fancy_regex::Regex as FancyRegex;
 use lazy_static::lazy_static;
 use regex::Regex;
+use serde::{Deserialize, Serialize};
 use std::collections::{HashMap, HashSet};
 
 lazy_static! {
@@ -33,6 +35,31 @@ lazy_static! {
     static ref CODE_BLOCK_END_REGEX: Regex = Regex::new(r"^```\s*$").unwrap();
 }
 
+/// Configuration for MD053 rule
+#[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
+#[serde(rename_all = "kebab-case")]
+pub struct MD053Config {
+    /// List of reference names to keep even if unused
+    #[serde(default = "default_ignored_definitions")]
+    pub ignored_definitions: Vec<String>,
+}
+
+impl Default for MD053Config {
+    fn default() -> Self {
+        Self {
+            ignored_definitions: default_ignored_definitions(),
+        }
+    }
+}
+
+fn default_ignored_definitions() -> Vec<String> {
+    Vec::new()
+}
+
+impl RuleConfig for MD053Config {
+    const RULE_NAME: &'static str = "MD053";
+}
+
 /// Rule MD053: Link and image reference definitions should be used
 ///
 /// See [docs/md053.md](../../docs/md053.md) for full documentation, configuration, and examples.
@@ -85,13 +112,22 @@ lazy_static! {
 /// When fixing issues, this rule removes unused reference definitions while preserving
 /// the document's structure, including handling proper blank line formatting around
 /// the removed definitions.
-#[derive(Clone, Default)]
-pub struct MD053LinkImageReferenceDefinitions {}
+#[derive(Clone)]
+pub struct MD053LinkImageReferenceDefinitions {
+    config: MD053Config,
+}
 
 impl MD053LinkImageReferenceDefinitions {
     /// Create a new instance of the MD053 rule
     pub fn new() -> Self {
-        Self {}
+        Self {
+            config: MD053Config::default(),
+        }
+    }
+
+    /// Create a new instance with the given configuration
+    pub fn from_config_struct(config: MD053Config) -> Self {
+        Self { config }
     }
 
     /// Unescape a reference string by removing backslashes before special characters.
@@ -114,7 +150,7 @@ impl MD053LinkImageReferenceDefinitions {
         doc_structure: &DocumentStructure,
     ) -> HashMap<String, Vec<(usize, usize)>> {
         let mut definitions: HashMap<String, Vec<(usize, usize)>> = HashMap::new();
-        
+
         // First, add all reference definitions from context
         for ref_def in &ctx.reference_defs {
             // Apply unescape to handle escaped characters in definitions
@@ -124,7 +160,7 @@ impl MD053LinkImageReferenceDefinitions {
                 .or_default()
                 .push((ref_def.line - 1, ref_def.line - 1)); // Convert to 0-indexed
         }
-        
+
         // Handle multi-line definitions that might not be fully captured by ctx.reference_defs
         let lines = &ctx.lines;
         let mut i = 0;
@@ -145,11 +181,11 @@ impl MD053LinkImageReferenceDefinitions {
                 while def_start > 0 && !REFERENCE_DEFINITION_REGEX.is_match(&lines[def_start].content) {
                     def_start -= 1;
                 }
-                
+
                 if let Some(caps) = REFERENCE_DEFINITION_REGEX.captures(&lines[def_start].content) {
                     let ref_id = caps.get(1).unwrap().as_str().trim();
                     let normalized_id = Self::unescape_reference(ref_id).to_lowercase();
-                    
+
                     // Update the end line for this definition
                     if let Some(ranges) = definitions.get_mut(&normalized_id) {
                         if let Some(last_range) = ranges.last_mut() {
@@ -204,7 +240,7 @@ impl MD053LinkImageReferenceDefinitions {
         //    and ensure they are not within code spans or code blocks.
         // Cache code spans once before the loop
         let code_spans = ctx.code_spans();
-        
+
         for (i, line_info) in ctx.lines.iter().enumerate() {
             let line_num = i + 1; // 1-indexed
 
@@ -254,8 +290,8 @@ impl MD053LinkImageReferenceDefinitions {
     ) -> Vec<(String, usize, usize)> {
         let mut unused = Vec::new();
         for (id, ranges) in definitions {
-            // If this id is not used anywhere, all its ranges are unused
-            if !usages.contains(id) {
+            // If this id is not used anywhere and is not in the ignored list, all its ranges are unused
+            if !usages.contains(id) && !self.is_ignored_definition(id) {
                 for (start, end) in ranges {
                     unused.push((id.clone(), *start, *end));
                 }
@@ -264,6 +300,14 @@ impl MD053LinkImageReferenceDefinitions {
         unused
     }
 
+    /// Check if a definition should be ignored (kept even if unused)
+    fn is_ignored_definition(&self, definition_id: &str) -> bool {
+        self.config
+            .ignored_definitions
+            .iter()
+            .any(|ignored| ignored.eq_ignore_ascii_case(definition_id))
+    }
+
     /// Clean up multiple consecutive blank lines that might be created after removing references
     fn clean_up_blank_lines(&self, content: &str) -> String {
         let lines: Vec<&str> = content.lines().collect();
@@ -296,6 +340,12 @@ impl MD053LinkImageReferenceDefinitions {
     }
 }
 
+impl Default for MD053LinkImageReferenceDefinitions {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 impl Rule for MD053LinkImageReferenceDefinitions {
     fn name(&self) -> &'static str {
         "MD053"
@@ -410,15 +460,37 @@ impl Rule for MD053LinkImageReferenceDefinitions {
         Ok(cleaned)
     }
 
+    /// Check if this rule should be skipped for performance
+    fn should_skip(&self, ctx: &crate::lint_context::LintContext) -> bool {
+        // Skip if content is empty or has no reference definitions
+        ctx.content.is_empty() || !ctx.content.contains("]:")
+    }
+
     fn as_any(&self) -> &dyn std::any::Any {
         self
     }
 
-    fn from_config(_config: &crate::config::Config) -> Box<dyn Rule>
+    fn default_config_section(&self) -> Option<(String, toml::Value)> {
+        let default_config = MD053Config::default();
+        let json_value = serde_json::to_value(&default_config).ok()?;
+        let toml_value = crate::rule_config_serde::json_to_toml_value(&json_value)?;
+        if let toml::Value::Table(table) = toml_value {
+            if !table.is_empty() {
+                Some((MD053Config::RULE_NAME.to_string(), toml::Value::Table(table)))
+            } else {
+                None
+            }
+        } else {
+            None
+        }
+    }
+
+    fn from_config(config: &crate::config::Config) -> Box<dyn Rule>
     where
         Self: Sized,
     {
-        Box::new(MD053LinkImageReferenceDefinitions::new())
+        let rule_config = crate::rule_config_serde::load_rule_config::<MD053Config>(config);
+        Box::new(MD053LinkImageReferenceDefinitions::from_config_struct(rule_config))
     }
 }
 
@@ -648,4 +720,77 @@ mod tests {
         // Test leading/trailing blank lines
         assert_eq!(rule.clean_up_blank_lines("\n\ntext\n\n"), "text");
     }
+
+    #[test]
+    fn test_ignored_definitions_config() {
+        // Test with ignored definitions
+        let config = MD053Config {
+            ignored_definitions: vec!["todo".to_string(), "draft".to_string()],
+        };
+        let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
+
+        let content = "[todo]: https://example.com/todo\n[draft]: https://example.com/draft\n[unused]: https://example.com/unused";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should only flag "unused", not "todo" or "draft"
+        assert_eq!(result.len(), 1);
+        assert!(result[0].message.contains("unused"));
+        assert!(!result[0].message.contains("todo"));
+        assert!(!result[0].message.contains("draft"));
+    }
+
+    #[test]
+    fn test_ignored_definitions_case_insensitive() {
+        // Test case-insensitive matching of ignored definitions
+        let config = MD053Config {
+            ignored_definitions: vec!["TODO".to_string()],
+        };
+        let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
+
+        let content = "[todo]: https://example.com/todo\n[unused]: https://example.com/unused";
+        let ctx = LintContext::new(content);
+        let result = rule.check(&ctx).unwrap();
+
+        // Should only flag "unused", not "todo" (matches "TODO" case-insensitively)
+        assert_eq!(result.len(), 1);
+        assert!(result[0].message.contains("unused"));
+        assert!(!result[0].message.contains("todo"));
+    }
+
+    #[test]
+    fn test_default_config_section() {
+        let rule = MD053LinkImageReferenceDefinitions::default();
+        let config_section = rule.default_config_section();
+
+        assert!(config_section.is_some());
+        let (name, value) = config_section.unwrap();
+        assert_eq!(name, "MD053");
+
+        // Should contain the ignored_definitions option with default empty array
+        if let toml::Value::Table(table) = value {
+            assert!(table.contains_key("ignored-definitions"));
+            assert_eq!(table["ignored-definitions"], toml::Value::Array(vec![]));
+        } else {
+            panic!("Expected TOML table");
+        }
+    }
+
+    #[test]
+    fn test_fix_respects_ignored_definitions() {
+        // Test that fix respects ignored definitions
+        let config = MD053Config {
+            ignored_definitions: vec!["template".to_string()],
+        };
+        let rule = MD053LinkImageReferenceDefinitions::from_config_struct(config);
+
+        let content = "[template]: https://example.com/template\n[unused]: https://example.com/unused\n\nSome content.";
+        let ctx = LintContext::new(content);
+        let fixed = rule.fix(&ctx).unwrap();
+
+        // Should keep template but remove unused
+        assert!(fixed.contains("[template]: https://example.com/template"));
+        assert!(!fixed.contains("[unused]: https://example.com/unused"));
+        assert!(fixed.contains("Some content."));
+    }
 }
