@@ -28,14 +28,13 @@ mod md030_test;
 mod md031_test;
 mod md032_test;
 mod md033_test;
-mod md034_test;
 mod md034_ipv6_test;
-mod md051_unicode_test;
+mod md034_test;
 mod md035_test;
 mod md036_test;
 mod md037_test;
-mod md038_test;
 mod md038_nested_backticks_test;
+mod md038_test;
 mod md039_test;
 mod md040_test;
 mod md041_test;
@@ -49,6 +48,7 @@ mod md048_test;
 mod md049_test;
 mod md050_test;
 mod md051_test;
+mod md051_unicode_test;
 mod md052_test;
 mod md053_additional_test;
 mod md053_test;
@@ -60,9 +60,18 @@ mod md058_test;
 
 // Unicode-specific test modules
 mod md001_unicode_test;
+mod md005_unicode_test;
 mod md006_unicode_test;
+mod md029_unicode_test;
 mod md054_unicode_test;
 
+// Cross-rule integration test modules
+mod emphasis_edge_cases_test;
+mod heading_edge_cases_test;
+mod inline_content_edge_cases_test;
+mod link_edge_cases_test;
+mod list_rules_integration_test;
+
 // Test cases for MD003 - Heading Style
 #[test]
 fn test_md003_fix_consistent_style() {
